@@ -25,30 +25,29 @@ This is a class that abstracts an object class with plugins.
 
 =cut
 
-has '_base' => (is => "rw", isa => "Str");
-has '_into' => (is => "rw", isa => "Str");
-has '_plugins' => (is => "rw", isa => "ArrayRef");
+has '_base' => (is => "rw", isa => "Str", init_arg => "base", );
+has '_into' => (is => "rw", isa => "Str", init_arg => "into", );
+has '_plugins' => (is => "rw", isa => "ArrayRef",
+    default => sub { []; }, lazy => 1
+);
 
 =head2 $plugger = Test::Run::Base::Plugger->new({base => $base, into => $into})
 
 $base is the base class and $into is the namespace to put everything into.
 
+=head2 BUILD
+
+For Moose.
+
 =cut
 
-sub _init
+sub BUILD
 {
-    my ($self, $args) = @_;
-
-    $self->maybe::next::method($args);
-
-    $self->_base($args->{base});
-    $self->_into($args->{into});
-
-    $self->_plugins([]);
+    my $self = shift;
 
     $self->_update_ISA();
-    
-    return 0;
+ 
+    return;
 }
 
 sub _update_ISA
@@ -64,18 +63,16 @@ sub _update_ISA
 
     foreach my $plugin (@{$self->_plugins()})
     {
-        $plugin->require();
-        if ($@)
+        if (!$plugin->require())
         {
             die $@;
         }
         push @$isa_ref, $plugin;
     }    
 
-    $base_class->require();
-    if ($@)
+    if (!$base_class->require())
     {
-        die $@
+        die $@;
     }
 
     push @$isa_ref, $base_class;
